@@ -5,7 +5,7 @@ use Module::Install::Base;
 
 use vars qw{$VERSION $ISCORE @ISA};
 BEGIN {
-	$VERSION = '0.72';
+	$VERSION = '0.73';
 	$ISCORE  = 1;
 	@ISA     = qw{Module::Install::Base};
 }
@@ -18,6 +18,14 @@ sub install_share {
 		$dir = 'share';
 	}
 
+	# If the module name and dist name don't math,
+	# the dist_dir won't subsequently work.
+	my $module_name = $self->name;
+	$module_name =~ s/-/::/;
+	unless ( $module_name eq $self->module_name ) {
+		die "For File::ShareDir::dist_dir to work, the module and distribution names much match";
+	}
+
 	$self->postamble(<<"END_MAKEFILE");
 config ::
 \t\$(NOECHO) \$(MOD_INSTALL) \\
